@@ -9,7 +9,7 @@ use Dancer2::Plugin::FormValidator::Validator;
 use Dancer2::Plugin::FormValidator::Config;
 use Types::Standard qw(InstanceOf HashRef ArrayRef);
 
-our $VERSION = '0.80';
+our $VERSION = '0.81';
 
 # Global var for saving last success validation valid input.
 my $valid_input;
@@ -56,7 +56,7 @@ has extensions => (
 
 has plugin_deferred => (
     is       => 'ro',
-    isa      => InstanceOf ['Dancer2::Plugin::Deferred'],
+    isa      => InstanceOf['Dancer2::Plugin::Deferred'],
     builder  => sub {
         return shift->app->with_plugin('Dancer2::Plugin::Deferred');
     }
@@ -171,20 +171,21 @@ Dancer2::Plugin::FormValidator - neat and easy to start form validation plugin f
 
 =head1 VERSION
 
-version 0.80
+version 0.81
 
 =head1 SYNOPSIS
 
     ### If you need a simple and easy validation in your project,
     ### then this module is what you need.
 
+    use Dancer2;
     use Dancer2::Plugin::FormValidator;
 
     ### First create form validation profile class.
 
     package RegisterForm {
-         use Moo;
-         with 'Dancer2::Plugin::FormValidator::Role::Profile';
+        use Moo;
+        with 'Dancer2::Plugin::FormValidator::Role::Profile';
 
         ### Here you need to declare validators.
 
@@ -265,14 +266,14 @@ It consists of dsl's keywords: validate, validator_language, errors.
 It has a set of built-in validators that can be extended by compatible modules (extensions).
 Also proved runtime switching between languages, so you can show proper error messages to users.
 
-Uses simple and declarative approach to validate forms:
+Uses simple and declarative approach to validate forms.
 
 =head2 Validator
 
 First, you need to create class which will implements
 at least one main role: Dancer2::Plugin::FormValidator::Role::Profile.
 
-This role requires profile method which should return a HashRef Data::FormValidator accepts:
+This role requires profile method which should return a I<HashRef> Data::FormValidator accepts:
 
     package RegisterForm
 
@@ -291,13 +292,15 @@ This role requires profile method which should return a HashRef Data::FormValida
 
 =head3 Profile method
 
-Profile method should always return a HashRef[ArrayRef] where keys are input fields names
+Profile method should always return a I<HashRef[ArrayRef]> where keys are input fields names
 and values are ArrayRef with list of validators.
 
 =head2 Application
 
 Then you need to set basic configuration:
 
+    use Dancer2;
+
      set plugins => {
             FormValidator => {
                 session => {
@@ -308,6 +311,7 @@ Then you need to set basic configuration:
 
 Now you can validate POST parameters in your controller:
 
+    use Dancer2;
     use Dancer2::Plugin::FormValidator;
     use RegisterForm;
 
@@ -329,8 +333,8 @@ Now you can validate POST parameters in your controller:
 
 =head2 Template
 
-In you template you have access to: $errors - this is HashRef with fields names as keys
-and error messages as ArrayRef values and $old - contains old input values.
+In you template you have access to: $errors - this is I<HashRef[ArrayRef]> with fields names as keys
+and error messages values and $old - contains old input values.
 
 Template app/register:
 
@@ -446,7 +450,7 @@ Accept arguments as hash:
 
 Profile is required, input and lang is optional.
 
-Returns valid input HashRef if validation succeed, otherwise returns undef.
+Returns valid input I<HashRef> if validation succeed, otherwise returns undef.
 
     ### You can use HashRef returned from validate.
 
@@ -475,8 +479,8 @@ Returns valid input HashRef if validation succeed, otherwise returns undef.
     validated(): HashRef|undef
 
 No arguments.
-Returns valid input HashRef if validate succeed.
-Undef value will be returned after first call within one validation process.
+Returns valid input I<HashRef> if validate succeed.
+I<Undef> value will be returned after first call within one validation process.
 
     my $valid_hash_ref = validated;
 
@@ -485,7 +489,7 @@ Undef value will be returned after first call within one validation process.
     errors(): HashRef
 
 No arguments.
-Returns HashRef[ArrayRef] if validation failed.
+Returns I<HashRef[ArrayRef]> if validation failed.
 
     my $errors_hash_multi = errors;
 
@@ -493,14 +497,18 @@ Returns HashRef[ArrayRef] if validation failed.
 
 =head3 accepted
 
+    accepted(): Bool
+
 Validates that field B<exists> and one of the listed: (yes on 1).
 
     field => [ qw(accepted) ]
 
-=head3 alpha:encoding=ascii
+=head3 alpha
+
+    alpha(String $encoding = 'a'): Bool
 
 Validate that string only contain of alphabetic symbols.
-By default encoding is ascii, i.e /^[[:alpha:]]+$/a.
+By default encoding is ascii, i.e B</^[[:alpha:]]+$/a>.
 
     field => [ qw(alpha) ]
 
@@ -508,12 +516,14 @@ To set encoding to unicode you need to pass 'u' argument:
 
     field => [ qw(alpha:u) ]
 
-Then the validation rule will be /^[[:alpha:]]+$/.
+Then the validation rule will be B</^[[:alpha:]]+$/>.
 
 =head3 alpha_num
 
+    alpha_num(String $encoding = 'a'): Bool
+
 Validate that string only contain of alphabetic symbols, underscore and numbers 0-9.
-By default encoding is ascii, i.e. /^\w+$/a.
+By default encoding is ascii, i.e. B</^\w+$/a>.
 
     field => [ qw(alpha_num) ]
 
@@ -521,21 +531,27 @@ To set encoding to unicode you need to pass 'u' argument:
 
     field => [ qw(alpha_num:u) ]
 
-Rule will be /^\w+$/.
+Rule will be B</^\w+$/>.
 
 =head3 email
 
-Validate that field is valid email(rfc822).
+    email(): Bool
+
+Validate that field is valid email(B<rfc822>).
 
     field => [ qw(email) ]
 
 =head3 email_dns
 
-Validate that field is valid email(rfc822) and dns exists.
+    email_dns(): Bool
+
+Validate that field is valid email(B<rfc822>) and dns exists.
 
     field => [ qw(email_dns) ]
 
-=head3 enum:value1,value2
+=head3 enum
+
+    enum(Array @values): Bool
 
 Validate that field is one of listed values.
 
@@ -543,29 +559,39 @@ Validate that field is one of listed values.
 
 =head3 integer
 
+    integer(): Bool
+
 Validate that field is integer.
 
     field => [ qw(integer) ]
 
-=head3 length_max:num
+=head3 length_max
+
+    length_max(Int $num): Bool
 
 Validate that string length <= num.
 
     field => [ qw(length_max:32) ]
 
-=head3 length_min:num
+=head3 length_min
+
+    length_min(Int $num): Bool
 
 Validate that string length >= num.
 
     field => [ qw(length_max:4) ]
 
-=head3 max:num
+=head3 max
+
+    max(Int $num): Bool
 
 Validate that field is number <= num.
 
     field => [ qw(max:32) ]
 
-=head3 min:num
+=head3 min
+
+    min(Int $num): Bool
 
 Validate that field is number >= num.
 
@@ -573,17 +599,23 @@ Validate that field is number >= num.
 
 =head3 numeric
 
+    numeric(): Bool
+
 Validate that field is number.
 
     field => [ qw(numeric) ]
 
 =head3 required
 
+    required(): Bool
+
 Validate that field exists and not empty string.
 
     field => [ qw(required) ]
 
-=head3 same:field
+=head3 same
+
+    same(String $field_name): bool
 
 Validate that field is exact value as another.
 
