@@ -2,12 +2,10 @@ package Dancer2::Plugin::FormValidator::Registry;
 
 use Moo;
 use Carp;
-use Module::Load;
+use Module::Load qw(autoload);
 use Types::Standard qw(ConsumerOf ArrayRef HashRef);
 use namespace::clean;
 
-my %validators;
-
 has extensions => (
     is        => 'ro',
     isa       => ArrayRef[ConsumerOf['Dancer2::Plugin::FormValidator::Role::Extension']],
@@ -18,7 +16,6 @@ has validators => (
     is        => 'ro',
     isa       => HashRef,
     lazy      => 1,
-    required  => 1,
     builder   => sub {
         my $self = shift;
         my %plugin_validators;
@@ -52,10 +49,6 @@ has validators => (
 sub get {
     my ($self, $name) = @_;
 
-    if (defined $validators{$name}) {
-        return $validators{$name};
-    }
-
     if (my $validator_struct = $self->validators->{$name}) {
         my $extension = $validator_struct->{extension};
         my $class     = $validator_struct->{validator};
@@ -72,8 +65,6 @@ sub get {
             Carp::croak "Validator: $class should implement $role\n";
         }
 
-        $validators{$name} = $validator;
-
         return $validator;
     }
 
@@ -84,9 +75,7 @@ sub _validators {
     return {
         accepted        => 'Dancer2::Plugin::FormValidator::Validator::Accepted',
         alpha           => 'Dancer2::Plugin::FormValidator::Validator::Alpha',
-        alpha_ascii     => 'Dancer2::Plugin::FormValidator::Validator::AlphaAscii',
         alpha_num       => 'Dancer2::Plugin::FormValidator::Validator::AlphaNum',
-        alpha_num_ascii => 'Dancer2::Plugin::FormValidator::Validator::AlphaNumAscii',
         enum            => 'Dancer2::Plugin::FormValidator::Validator::Enum',
         email           => 'Dancer2::Plugin::FormValidator::Validator::Email',
         email_dns       => 'Dancer2::Plugin::FormValidator::Validator::EmailDns',
